@@ -66,12 +66,6 @@ public:
      */
     QHash<QString, KCalendarCore::Incidence::Ptr> mIncidencesByIdentifier;
 
-    /**
-     * List of all deleted incidences.
-     * First indexed by incidence->type(), then by incidence->uid();
-     */
-    QMultiHash<QString, Incidence::Ptr> mDeletedIncidences[incidenceTypeCount];
-
     /**
      * Contains incidences ( to-dos; non-recurring, non-multiday events; journals; )
      * indexed by start/due date.
@@ -91,8 +85,6 @@ public:
 
     bool deleteIncidence(const QString &uid, IncidenceBase::IncidenceType type, const QDateTime &recurrenceId = {});
 
-    Incidence::Ptr deletedIncidence(const QString &uid, const QDateTime &recurrenceId, IncidenceBase::IncidenceType type) const;
-
     void deleteAllIncidences(IncidenceBase::IncidenceType type);
 
     template<typename IncidenceType, typename Key>
@@ -163,7 +155,20 @@ MemoryCalendar::MemoryCalendar(const QByteArray &timeZoneId)
 
 MemoryCalendar::~MemoryCalendar()
 {
-    close(); // NOLINT false clang-analyzer-optin.cplusplus.VirtualCall
+    setObserversEnabled(false);
+
+    // Don't call the virtual function deleteEvents() etc, the base class might have
+    // other ways of deleting the data.
+    d->deleteAllIncidences(Incidence::TypeEvent);
+    d->deleteAllIncidences(Incidence::TypeTodo);
+    d->deleteAllIncidences(Incidence::TypeJournal);
+
+    d->mIncidencesByIdentifier.clear();
+
+    setModified(false);
+
+    setObserversEnabled(true);
+
     delete d;
 }
 
@@ -184,34 +189,8 @@ void MemoryCalendar::doSetTimeZone(const QTimeZone &timeZone)
     }
 }
 
-void MemoryCalendar::close()
-{
-    setObserversEnabled(false);
-
-    // Don't call the virtual function deleteEvents() etc, the base class might have
-    // other ways of deleting the data.
-    d->deleteAllIncidences(Incidence::TypeEvent);
-    d->deleteAllIncidences(Incidence::TypeTodo);
-    d->deleteAllIncidences(Incidence::TypeJournal);
-
-    d->mIncidencesByIdentifier.clear();
-    for (auto &table : d->mDeletedIncidences) {
-        table.clear();
-    }
-
-    clearNotebookAssociations();
-
-    setModified(false);
-
-    setObserversEnabled(true);
-}
-
 bool MemoryCalendar::deleteIncidence(const Incidence::Ptr &incidence)
 {
-    // Handle orphaned children
-    // relations is an Incidence's property, not a Todo's, so
-    // we remove relations in deleteIncidence, not in deleteTodo.
-    removeRelations(incidence);
     // Notify while the incidence is still available,
     // this is necessary so korganizer still has time to query for exceptions
     notifyIncidenceAboutToBeDeleted(incidence);
@@ -221,9 +200,6 @@ bool MemoryCalendar::deleteIncidence(const Incidence::Ptr &incidence)
     bool deleted = d->deleteIncidence(uid, type, incidence->recurrenceId());
     if (deleted) {
         setModified(true);
-        if (deletionTracking()) {
-            d->mDeletedIncidences[type].insert(uid, incidence);
-        }
 
         // Delete child-incidences.
         if (!incidence->hasRecurrenceId() && incidence->recurs()) {
@@ -296,15 +272,6 @@ Incidence::Ptr MemoryCalendar::Private::incidence(const QString &uid, Incidence:
     return findIncidence(mIncidences[type], uid, recurrenceId);
 }
 
-Incidence::Ptr MemoryCalendar::Private::deletedIncidence(const QString &uid, const QDateTime &recurrenceId, IncidenceBase::IncidenceType type) const
-{
-    if (!q->deletionTracking()) {
-        return Incidence::Ptr();
-    }
-
-    return findIncidence(mDeletedIncidences[type], uid, recurrenceId);
-}
-
 void MemoryCalendar::Private::insertIncidence(const Incidence::Ptr &incidence)
 {
     const QString uid = incidence->uid();
@@ -335,8 +302,6 @@ bool MemoryCalendar::addIncidence(const Incidence::Ptr &incidence)
 
     incidence->registerObserver(this);
 
-    setupRelations(incidence);
-
     setModified(true);
 
     return true;
@@ -362,11 +327,6 @@ Event::Ptr MemoryCalendar::event(const QString &uid, const QDateTime &recurrence
     return d->incidence(uid, Incidence::TypeEvent, recurrenceId).staticCast<Event>();
 }
 
-Event::Ptr MemoryCalendar::deletedEvent(const QString &uid, const QDateTime &recurrenceId) const
-{
-    return d->deletedIncidence(uid, recurrenceId, Incidence::TypeEvent).staticCast<Event>();
-}
-
 bool MemoryCalendar::addTodo(const Todo::Ptr &todo)
 {
     return addIncidence(todo);
@@ -387,25 +347,11 @@ Todo::Ptr MemoryCalendar::todo(const QString &uid, const QDateTime &recurrenceId
     return d->incidence(uid, Incidence::TypeTodo, recurrenceId).staticCast<Todo>();
 }
 
-Todo::Ptr MemoryCalendar::deletedTodo(const QString &uid, const QDateTime &recurrenceId) const
-{
-    return d->deletedIncidence(uid, recurrenceId, Incidence::TypeTodo).staticCast<Todo>();
-}
-
 Todo::List MemoryCalendar::rawTodos(TodoSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortTodos(d->castIncidenceList<Todo>(d->mIncidences[Incidence::TypeTodo]), sortField, sortDirection);
 }
 
-Todo::List MemoryCalendar::deletedTodos(TodoSortField sortField, SortDirection sortDirection) const
-{
-    if (!deletionTracking()) {
-        return Todo::List();
-    }
-
-    return Calendar::sortTodos(d->castIncidenceList<Todo>(d->mDeletedIncidences[Incidence::TypeTodo]), sortField, sortDirection);
-}
-
 Todo::List MemoryCalendar::todoInstances(const Incidence::Ptr &todo, TodoSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortTodos(d->incidenceInstances<Todo>(Incidence::TypeTodo, todo), sortField, sortDirection);
@@ -441,9 +387,6 @@ Todo::List MemoryCalendar::rawTodos(const QDate &start, const QDate &end, const
     // Get todos
     for (const auto &incidence : d->mIncidences[Incidence::TypeTodo]) {
         const auto todo = incidence.staticCast<Todo>();
-        if (!isVisible(todo)) {
-            continue;
-        }
 
         QDateTime rStart = todo->hasDueDate() ? todo->dtDue() : todo->hasStartDate() ? todo->dtStart() : QDateTime();
         if (!rStart.isValid()) {
@@ -480,11 +423,6 @@ Todo::List MemoryCalendar::rawTodos(const QDate &start, const QDate &end, const
     return todoList;
 }
 
-Alarm::List MemoryCalendar::alarmsTo(const QDateTime &to) const
-{
-    return alarms(QDateTime(QDate(1900, 1, 1), QTime(0, 0, 0)), to);
-}
-
 Alarm::List MemoryCalendar::alarms(const QDateTime &from, const QDateTime &to, bool excludeBlockedAlarms) const
 {
     Q_UNUSED(excludeBlockedAlarms);
@@ -586,7 +524,7 @@ Event::List MemoryCalendar::rawEventsForDate(const QDate &date, const QTimeZone
     if (timeZone.isValid() && timeZone != this->timeZone()) {
         // We cannot use the hash table on date, since time zone is different.
         eventList = rawEvents(date, date, timeZone, false);
-        return Calendar::sortEvents(eventList, sortField, sortDirection);
+        return Calendar::sortEvents(std::move(eventList), sortField, sortDirection);
     }
 
     // Iterate over all non-recurring, single-day events that start on this date
@@ -621,7 +559,7 @@ Event::List MemoryCalendar::rawEventsForDate(const QDate &date, const QTimeZone
         }
     }
 
-    return Calendar::sortEvents(eventList, sortField, sortDirection);
+    return Calendar::sortEvents(std::move(eventList), sortField, sortDirection);
 }
 
 Event::List MemoryCalendar::rawEvents(const QDate &start, const QDate &end, const QTimeZone &timeZone, bool inclusive) const
@@ -679,25 +617,11 @@ Event::List MemoryCalendar::rawEvents(const QDate &start, const QDate &end, cons
     return eventList;
 }
 
-Event::List MemoryCalendar::rawEventsForDate(const QDateTime &kdt) const
-{
-    return rawEventsForDate(kdt.date(), kdt.timeZone());
-}
-
 Event::List MemoryCalendar::rawEvents(EventSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortEvents(d->castIncidenceList<Event>(d->mIncidences[Incidence::TypeEvent]), sortField, sortDirection);
 }
 
-Event::List MemoryCalendar::deletedEvents(EventSortField sortField, SortDirection sortDirection) const
-{
-    if (!deletionTracking()) {
-        return Event::List();
-    }
-
-    return Calendar::sortEvents(d->castIncidenceList<Event>(d->mDeletedIncidences[Incidence::TypeEvent]), sortField, sortDirection);
-}
-
 Event::List MemoryCalendar::eventInstances(const Incidence::Ptr &event, EventSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortEvents(d->incidenceInstances<Event>(Incidence::TypeEvent, event), sortField, sortDirection);
@@ -723,25 +647,11 @@ Journal::Ptr MemoryCalendar::journal(const QString &uid, const QDateTime &recurr
     return d->incidence(uid, Incidence::TypeJournal, recurrenceId).staticCast<Journal>();
 }
 
-Journal::Ptr MemoryCalendar::deletedJournal(const QString &uid, const QDateTime &recurrenceId) const
-{
-    return d->deletedIncidence(uid, recurrenceId, Incidence::TypeJournal).staticCast<Journal>();
-}
-
 Journal::List MemoryCalendar::rawJournals(JournalSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortJournals(d->castIncidenceList<Journal>(d->mIncidences[Incidence::TypeJournal]), sortField, sortDirection);
 }
 
-Journal::List MemoryCalendar::deletedJournals(JournalSortField sortField, SortDirection sortDirection) const
-{
-    if (!deletionTracking()) {
-        return Journal::List();
-    }
-
-    return Calendar::sortJournals(d->castIncidenceList<Journal>(d->mDeletedIncidences[Incidence::TypeJournal]), sortField, sortDirection);
-}
-
 Journal::List MemoryCalendar::journalInstances(const Incidence::Ptr &journal, JournalSortField sortField, SortDirection sortDirection) const
 {
     return Calendar::sortJournals(d->incidenceInstances<Journal>(Incidence::TypeJournal, journal), sortField, sortDirection);
@@ -769,3 +679,5 @@ void MemoryCalendar::virtual_hook(int id, void *data)
     Q_UNUSED(data);
     Q_ASSERT(false);
 }
+
+#include "moc_memorycalendar.cpp"
